.. index::
    single: prequest; --help

.. _prequest_script:

.. autoprogram:: pyramid.scripts.prequest:PRequestCommand.parser
    :prog: prequest

.. seealso:: :ref:`invoking_a_request` and :ref:`running-pscripts`.
